==> qtjambi-charts-debuginfo-windows-x64-6.6.1.jar: sources/QtJambiCharts/QBarLegendMarker_shell.h <==
#ifndef QBARLEGENDMARKER_SHELL_H
#define QBARLEGENDMARKER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qbarlegendmarker.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qabstractbarseries.h>
#include <QtCharts/qbarset.h>
#include <QtCharts/qlegend.h>
#include <QtCharts/qlegendmarker.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qbrush.h>
#include <QtGui/qfont.h>
#include <QtGui/qpen.h>
#include <QtJambi/RegistryAPI>


class QBarLegendMarker_shell : public QBarLegendMarker, public QtJambiShellInterface
{
public:
    QBarLegendMarker_shell(QAbstractBarSeries* series0, QBarSet* barset1, QLegend* legend2, QObject* parent3 = nullptr);
    ~QBarLegendMarker_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QAbstractBarSeries* series() override;
    void timerEvent(QTimerEvent* event0) override;
    QLegendMarker::LegendMarkerType type() override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QBarLegendMarker_access : public QBarLegendMarker
{
    jobject __qt_series(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_type(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QBARLEGENDMARKER_SHELL_H

==> qtjambi-charts-debuginfo-windows-x64-6.7.1.jar: sources/QtJambiCharts/QBarLegendMarker_shell.h <==
#ifndef QBARLEGENDMARKER_SHELL_H
#define QBARLEGENDMARKER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtCharts/qbarlegendmarker.h>
#include <QtJambi/QtJambiAPI>
#include <QtCharts/qabstractbarseries.h>
#include <QtCharts/qbarset.h>
#include <QtCharts/qlegend.h>
#include <QtCharts/qlegendmarker.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qbrush.h>
#include <QtGui/qfont.h>
#include <QtGui/qpen.h>
#include <QtJambi/RegistryAPI>


class QBarLegendMarker_shell : public QBarLegendMarker, public QtJambiShellInterface
{
public:
    QBarLegendMarker_shell(QAbstractBarSeries* series0, QBarSet* barset1, QLegend* legend2, QObject* parent3 = nullptr);
    ~QBarLegendMarker_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QBarLegendMarker_mshell;
    friend class QBarLegendMarker_oshell;
};


class QBarLegendMarker_mshell : public QBarLegendMarker_shell
{
public:
    using QBarLegendMarker_shell::QBarLegendMarker_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QBarLegendMarker_oshell : public QBarLegendMarker_mshell
{
public:
    using QBarLegendMarker_mshell::QBarLegendMarker_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QAbstractBarSeries* series() override;
    void timerEvent(QTimerEvent* event0) override;
    QLegendMarker::LegendMarkerType type() override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QBarLegendMarker_access : public QBarLegendMarker
{
    jobject __qt_series(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_type(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QBARLEGENDMARKER_SHELL_H
